from unittest.mock import patch

import pytest

from gso.products.product_types.switch import Switch
from test.workflows import assert_complete, extract_state, run_workflow


@pytest.mark.workflow()
@patch("gso.services.netbox_client.NetboxClient.delete_device")
@patch("gso.services.infoblox.delete_host_by_fqdn")
def test_terminate_switch(mock_delete_host_by_fqdn, mock_delete_device, switch_subscription_factory, faker):
    subscription_id = switch_subscription_factory()
    initial_switch_data = [{"subscription_id": subscription_id}, {"tt_number": faker.tt_number()}]
    result, _, _ = run_workflow("terminate_switch", initial_switch_data)
    assert_complete(result)

    state = extract_state(result)
    subscription_id = state["subscription_id"]
    subscription = Switch.from_subscription(subscription_id)
    assert subscription.status == "terminated"
    assert mock_delete_device.call_count == 1
    assert mock_delete_host_by_fqdn.call_count == 1
