from unittest.mock import patch

import pytest

from gso.products.product_types.switch import Switch
from test.workflows import (
    assert_complete,
    assert_lso_success,
    extract_state,
    run_workflow,
)


@pytest.mark.workflow()
@patch("gso.services.lso_client._send_request")
@patch("gso.services.netbox_client.NetboxClient.get_device_by_name")
def test_validate_switch_success(
    mock_get_device_by_name,
    mock_execute_playbook,
    switch_subscription_factory,
    faker,
    data_config_filename,
    geant_partner,
):
    #  Run workflow
    subscription_id = switch_subscription_factory()
    initial_switch_data = [{"subscription_id": subscription_id}]
    result, process_stat, step_log = run_workflow("validate_switch", initial_switch_data)

    result, step_log = assert_lso_success(result, process_stat, step_log)

    assert_complete(result)
    state = extract_state(result)
    subscription = Switch.from_subscription(state["subscription_id"])

    assert subscription.status == "active"
    assert mock_execute_playbook.call_count == 1
    assert mock_get_device_by_name.call_count == 1
